HyronTools
==========

CLI Interface for Hyron
-----------------------

### Introduction

These CLI tools provide a simple CLI interface for Hyron functionality.
Unlike the Hyron library itself, this package is not rigourously tested.
This simply serves as a reference implementation, allow for a simple demonstration of Hyron's capabilities.
